from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultsCls:
	"""Results commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("results", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:UNCertainty:DATA:RESults \n
		Snippet: driver.applications.k30NoiseFigure.calculate.uncertainty.data.results.set(state = False, window = repcap.Window.Default) \n
		This command turns automatic determination of the DUT characteristics for the calculation of the uncertainty on and off. \n
			:param state: ON | 1 The application calculates the uncertainty with the DUT characteristics ('noise figure', 'gain' and frequency) resulting from the 'noise figure' measurement. OFF | 0 The application calculates the uncertainty with the DUT characteristics ('noise figure', 'gain' and frequency) based on the values you have defined manually.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:UNCertainty:DATA:RESults {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:UNCertainty:DATA:RESults \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.calculate.uncertainty.data.results.get(window = repcap.Window.Default) \n
		This command turns automatic determination of the DUT characteristics for the calculation of the uncertainty on and off. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | 1 The application calculates the uncertainty with the DUT characteristics ('noise figure', 'gain' and frequency) resulting from the 'noise figure' measurement. OFF | 0 The application calculates the uncertainty with the DUT characteristics ('noise figure', 'gain' and frequency) based on the values you have defined manually."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNCertainty:DATA:RESults?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GeneratorCls:
	"""Generator commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("generator", core, parent)

	@property
	def control(self):
		"""control commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	@property
	def initialise(self):
		"""initialise commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_initialise'):
			from .Initialise import InitialiseCls
			self._initialise = InitialiseCls(self._core, self._cmd_group)
		return self._initialise

	@property
	def switch(self):
		"""switch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_switch'):
			from .Switch import SwitchCls
			self._switch = SwitchCls(self._core, self._cmd_group)
		return self._switch

	def clone(self) -> 'GeneratorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GeneratorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtransitionCls:
	"""Ptransition commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ptransition", core, parent)

	def set(self, bit_definition: int, channel_name: str = None, window=repcap.Window.Default) -> None:
		"""SCPI: STATus:QUEStionable:MODulation<Window>:FSK:PTRansition \n
		Snippet: driver.applications.k70Vsa.status.questionable.modulation.fsk.ptransition.set(bit_definition = 1, channel_name = '1', window = repcap.Window.Default) \n
		These commands control the Positive TRansition part of a register. Setting a bit causes a 0 to 1 transition in the
		corresponding bit of the associated register. The transition also writes a 1 into the associated bit of the corresponding
		EVENt register. \n
			:param bit_definition: Range: 0 to 65535
			:param channel_name: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('bit_definition', bit_definition, DataType.Integer), ArgSingle('channel_name', channel_name, DataType.String, None, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'STATus:QUEStionable:MODulation{window_cmd_val}:FSK:PTRansition {param}'.rstrip())

	# noinspection PyTypeChecker
	class PtransitionStruct(StructBase):
		"""Response structure. Fields: \n
			- Bit_Definition: int: Range: 0 to 65535
			- Channel_Name: str: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel."""
		__meta_args_list = [
			ArgStruct.scalar_int('Bit_Definition'),
			ArgStruct.scalar_str('Channel_Name')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Bit_Definition: int = None
			self.Channel_Name: str = None

	def get(self, window=repcap.Window.Default) -> PtransitionStruct:
		"""SCPI: STATus:QUEStionable:MODulation<Window>:FSK:PTRansition \n
		Snippet: value: PtransitionStruct = driver.applications.k70Vsa.status.questionable.modulation.fsk.ptransition.get(window = repcap.Window.Default) \n
		These commands control the Positive TRansition part of a register. Setting a bit causes a 0 to 1 transition in the
		corresponding bit of the associated register. The transition also writes a 1 into the associated bit of the corresponding
		EVENt register. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')
			:return: structure: for return value, see the help for PtransitionStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'STATus:QUEStionable:MODulation{window_cmd_val}:FSK:PTRansition?', self.__class__.PtransitionStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.ProbeSetupMode, probe=repcap.Probe.Default) -> None:
		"""SCPI: [SENSe]:PROBe<pb>:SETup:MODE \n
		Snippet: driver.sense.probe.setup.mode.set(mode = enums.ProbeSetupMode.NOACtion, probe = repcap.Probe.Default) \n
		No command help available \n
			:param mode: No help available
			:param probe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Probe')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ProbeSetupMode)
		probe_cmd_val = self._cmd_group.get_repcap_cmd_value(probe, repcap.Probe)
		self._core.io.write(f'SENSe:PROBe{probe_cmd_val}:SETup:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, probe=repcap.Probe.Default) -> enums.ProbeSetupMode:
		"""SCPI: [SENSe]:PROBe<pb>:SETup:MODE \n
		Snippet: value: enums.ProbeSetupMode = driver.sense.probe.setup.mode.get(probe = repcap.Probe.Default) \n
		No command help available \n
			:param probe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Probe')
			:return: mode: No help available"""
		probe_cmd_val = self._cmd_group.get_repcap_cmd_value(probe, repcap.Probe)
		response = self._core.io.query_str(f'SENSe:PROBe{probe_cmd_val}:SETup:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ProbeSetupMode)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TextCls:
	"""Text commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("text", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:TEXT \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.text.set(filename = '1') \n
		Defines the description for the frame structure in a previously loaded file. This command is only available if the
		additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. Note that the file must be loaded for editing
		before the description can be defined using this command (see [SENSe:]DDEMod:PATTern:FRAMe:EDIT) . \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:TEXT {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:TEXT \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.text.get() \n
		Defines the description for the frame structure in a previously loaded file. This command is only available if the
		additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. Note that the file must be loaded for editing
		before the description can be defined using this command (see [SENSe:]DDEMod:PATTern:FRAMe:EDIT) . \n
			:return: filename: string"""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:TEXT?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, op_mode: enums.InstrumentMode) -> None:
		"""SCPI: INSTrument:MODE \n
		Snippet: driver.instrument.mode.set(op_mode = enums.InstrumentMode.MSRanalyzer) \n
		No command help available \n
			:param op_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(op_mode, enums.InstrumentMode)
		self._core.io.write_with_opc(f'INSTrument:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.InstrumentMode:
		"""SCPI: INSTrument:MODE \n
		Snippet: value: enums.InstrumentMode = driver.instrument.mode.get() \n
		No command help available \n
			:return: op_mode: No help available"""
		response = self._core.io.query_str_with_opc(f'INSTrument:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.InstrumentMode)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ContentCls:
	"""Content commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("content", core, parent)

	def set(self, content: enums.HardcopyContent) -> None:
		"""SCPI: HCOPy:CONTent \n
		Snippet: driver.hardCopy.content.set(content = enums.HardcopyContent.HCOPy) \n
		This command determines the type of content included in the printout. This setting is independent of the printing device. \n
			:param content: WINDows | HCOPy WINDows Includes only the selected windows in the printout. All currently active windows for the current channel (or 'MultiView') are available for selection. How many windows are printed on a each page of the printout is defined by method RsFswp.HardCopy.Page.Window.Count.set. This option is not available when copying to the clipboard (HCOP:DEST 'SYST:COMM:CLIP' or an image file (see method RsFswp.HardCopy.Device.Language.set) . If the destination is currently set to an image file or the clipboard, it is automatically changed to be a PDF file for the currently selected printing device. HCOPy Selects all measurement results displayed on the screen for the current channel (or 'MultiView') : diagrams, traces, markers, marker lists, limit lines, etc., including the channel bar and status bar, for printout on a single page. Displayed items belonging to the software user interface (e.g. softkeys) are not included. The size and position of the elements in the printout is identical to the screen display.
		"""
		param = Conversions.enum_scalar_to_str(content, enums.HardcopyContent)
		self._core.io.write(f'HCOPy:CONTent {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.HardcopyContent:
		"""SCPI: HCOPy:CONTent \n
		Snippet: value: enums.HardcopyContent = driver.hardCopy.content.get() \n
		This command determines the type of content included in the printout. This setting is independent of the printing device. \n
			:return: content: WINDows | HCOPy WINDows Includes only the selected windows in the printout. All currently active windows for the current channel (or 'MultiView') are available for selection. How many windows are printed on a each page of the printout is defined by method RsFswp.HardCopy.Page.Window.Count.set. This option is not available when copying to the clipboard (HCOP:DEST 'SYST:COMM:CLIP' or an image file (see method RsFswp.HardCopy.Device.Language.set) . If the destination is currently set to an image file or the clipboard, it is automatically changed to be a PDF file for the currently selected printing device. HCOPy Selects all measurement results displayed on the screen for the current channel (or 'MultiView') : diagrams, traces, markers, marker lists, limit lines, etc., including the channel bar and status bar, for printout on a single page. Displayed items belonging to the software user interface (e.g. softkeys) are not included. The size and position of the elements in the printout is identical to the screen display."""
		response = self._core.io.query_str(f'HCOPy:CONTent?')
		return Conversions.str_to_scalar_enum(response, enums.HardcopyContent)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 12 total commands, 6 Subgroups, 1 group commands
	Repeated Capability: SubBlock, default value after init: SubBlock.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_subBlock_get', 'repcap_subBlock_set', repcap.SubBlock.Nr1)

	def repcap_subBlock_set(self, subBlock: repcap.SubBlock) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SubBlock.Default
		Default value after init: SubBlock.Nr1"""
		self._cmd_group.set_repcap_enum_value(subBlock)

	def repcap_subBlock_get(self) -> repcap.SubBlock:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def result(self):
		"""result commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	@property
	def standard(self):
		"""standard commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_standard'):
			from .Standard import StandardCls
			self._standard = StandardCls(self._core, self._cmd_group)
		return self._standard

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def auto(self):
		"""auto commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def preset(self, standard: enums.TechnologyStandardB, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>:PRESet \n
		Snippet: driver.calculate.marker.function.power.preset(standard = enums.TechnologyStandardB.AWLan, window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param standard: (enum or string) No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
		"""
		param = Conversions.enum_ext_scalar_to_str(standard, enums.TechnologyStandardB)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:PRESet {param}')

	def clone(self) -> 'PowerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PowerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, gate_length: float) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:LENGth \n
		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.length.set(gate_length = 1.0) \n
		This command defines the gate length. \n
			:param gate_length: Range: 125 ns to 30 s, Unit: S
		"""
		param = Conversions.decimal_value_to_str(gate_length)
		self._core.io.write(f'SENSe:SWEep:EGATe:LENGth {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:EGATe:LENGth \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.sweep.egate.length.get() \n
		This command defines the gate length. \n
			:return: gate_length: Range: 125 ns to 30 s, Unit: S"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:LENGth?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CpathCls:
	"""Cpath commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cpath", core, parent)

	def set(self, path_to_calibrate: enums.PathToCalibrate) -> None:
		"""SCPI: DIAGnostic:SERVice:INPut:RF:CPATh \n
		Snippet: driver.diagnostic.service.inputPy.rf.cpath.set(path_to_calibrate = enums.PathToCalibrate.FULL) \n
		No command help available \n
			:param path_to_calibrate: No help available
		"""
		param = Conversions.enum_scalar_to_str(path_to_calibrate, enums.PathToCalibrate)
		self._core.io.write(f'DIAGnostic:SERVice:INPut:RF:CPATh {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PathToCalibrate:
		"""SCPI: DIAGnostic:SERVice:INPut:RF:CPATh \n
		Snippet: value: enums.PathToCalibrate = driver.diagnostic.service.inputPy.rf.cpath.get() \n
		No command help available \n
			:return: path_to_calibrate: No help available"""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:INPut:RF:CPATh?')
		return Conversions.str_to_scalar_enum(response, enums.PathToCalibrate)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NormalizeCls:
	"""Normalize commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("normalize", core, parent)

	@property
	def value(self):
		"""value commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_value'):
			from .Value import ValueCls
			self._value = ValueCls(self._core, self._cmd_group)
		return self._value

	@property
	def cfdrift(self):
		"""cfdrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cfdrift'):
			from .Cfdrift import CfdriftCls
			self._cfdrift = CfdriftCls(self._core, self._cmd_group)
		return self._cfdrift

	@property
	def fdError(self):
		"""fdError commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdError'):
			from .FdError import FdErrorCls
			self._fdError = FdErrorCls(self._core, self._cmd_group)
		return self._fdError

	@property
	def iqOffset(self):
		"""iqOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqOffset'):
			from .IqOffset import IqOffsetCls
			self._iqOffset = IqOffsetCls(self._core, self._cmd_group)
		return self._iqOffset

	@property
	def iqImbalance(self):
		"""iqImbalance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqImbalance'):
			from .IqImbalance import IqImbalanceCls
			self._iqImbalance = IqImbalanceCls(self._core, self._cmd_group)
		return self._iqImbalance

	@property
	def adroop(self):
		"""adroop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adroop'):
			from .Adroop import AdroopCls
			self._adroop = AdroopCls(self._core, self._cmd_group)
		return self._adroop

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import ChannelCls
			self._channel = ChannelCls(self._core, self._cmd_group)
		return self._channel

	@property
	def srError(self):
		"""srError commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srError'):
			from .SrError import SrErrorCls
			self._srError = SrErrorCls(self._core, self._cmd_group)
		return self._srError

	def clone(self) -> 'NormalizeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NormalizeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PeriodCls:
	"""Period commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("period", core, parent)

	def set(self, pulse_period: float) -> None:
		"""SCPI: SOURce:GENerator:PULSe:PERiod \n
		Snippet: driver.applications.k30NoiseFigure.source.generator.pulse.period.set(pulse_period = 1.0) \n
		No command help available \n
			:param pulse_period: No help available
		"""
		param = Conversions.decimal_value_to_str(pulse_period)
		self._core.io.write(f'SOURce:GENerator:PULSe:PERiod {param}')

	def get(self) -> float:
		"""SCPI: SOURce:GENerator:PULSe:PERiod \n
		Snippet: value: float = driver.applications.k30NoiseFigure.source.generator.pulse.period.get() \n
		No command help available \n
			:return: pulse_period: No help available"""
		response = self._core.io.query_str(f'SOURce:GENerator:PULSe:PERiod?')
		return Conversions.str_to_float(response)



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, frequency: List[float], loss: List[float]) -> None:
		"""SCPI: [SENSe]:CORRection:LOSS:OUTPut:TABLe[:DATA] \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.loss.output.table.data.set(frequency = [1.1, 2.2, 3.3], loss = [1.1, 2.2, 3.3]) \n
		This command defines the contents of the currently selected output loss table. The table should contain an output loss
		for all measurement points. Each entry of the loss table consists of one measurement point and the corresponding loss.
		The table can contain up to 10001 entries. If you create a new table with this command, it will overwrite the current
		entries of the frequency list. \n
			:param frequency: Frequency of the measurement point. Range: 0 dB to 999.99 dB, Unit: HZ
			:param loss: Loss of the measurement point. Range: -999.99 dB to 999.99 dB, Unit: DB
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('frequency', frequency, DataType.FloatList, None), ArgSingle.as_open_list('loss', loss, DataType.FloatList, None))
		self._core.io.write(f'SENSe:CORRection:LOSS:OUTPut:TABLe:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Frequency: List[float]: Frequency of the measurement point. Range: 0 dB to 999.99 dB, Unit: HZ
			- Loss: List[float]: Loss of the measurement point. Range: -999.99 dB to 999.99 dB, Unit: DB"""
		__meta_args_list = [
			ArgStruct('Frequency', DataType.FloatList, None, False, True, 1),
			ArgStruct('Loss', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency: List[float] = None
			self.Loss: List[float] = None

	def get(self) -> DataStruct:
		"""SCPI: [SENSe]:CORRection:LOSS:OUTPut:TABLe[:DATA] \n
		Snippet: value: DataStruct = driver.applications.k30NoiseFigure.sense.correction.loss.output.table.data.get() \n
		This command defines the contents of the currently selected output loss table. The table should contain an output loss
		for all measurement points. Each entry of the loss table consists of one measurement point and the corresponding loss.
		The table can contain up to 10001 entries. If you create a new table with this command, it will overwrite the current
		entries of the frequency list. \n
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:CORRection:LOSS:OUTPut:TABLe:DATA?', self.__class__.DataStruct())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LanguageCls:
	"""Language commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("language", core, parent)

	def set(self, language: str) -> None:
		"""SCPI: SYSTem:LANGuage \n
		Snippet: driver.system.language.set(language = '1') \n
		This command selects the system language. \n
			:param language: String containing the name of the language. 'SCPI' SCPI language. 'PSA' PSA emulation. For a list of supported commands, see 'Reference: command set of emulated PSA models'.
		"""
		param = Conversions.value_to_quoted_str(language)
		self._core.io.write(f'SYSTem:LANGuage {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:LANGuage \n
		Snippet: value: str = driver.system.language.get() \n
		This command selects the system language. \n
			:return: language: String containing the name of the language. 'SCPI' SCPI language. 'PSA' PSA emulation. For a list of supported commands, see 'Reference: command set of emulated PSA models'."""
		response = self._core.io.query_str(f'SYSTem:LANGuage?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.applications.k30NoiseFigure.initiate.immediate.set() \n
		This command starts a (single) new measurement. You can synchronize to the end of the measurement with *OPC, *OPC?
		or *WAI. For details on synchronization see Remote control via SCPI. \n
		"""
		self._core.io.write(f'INITiate:IMMediate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate[:IMMediate] \n
		Snippet: driver.applications.k30NoiseFigure.initiate.immediate.set_with_opc() \n
		This command starts a (single) new measurement. You can synchronize to the end of the measurement with *OPC, *OPC?
		or *WAI. For details on synchronization see Remote control via SCPI. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:IMMediate', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self) -> float:
		"""SCPI: SOURce:POWer:SEQuence:RESult \n
		Snippet: value: float = driver.applications.k30NoiseFigure.source.power.sequence.result.get() \n
		No command help available \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'SOURce:POWer:SEQuence:RESult?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, freq_high: bool) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH:STATe \n
		Snippet: driver.applications.k50Spurious.sense.mixer.harmonic.high.state.set(freq_high = False) \n
		This command specifies whether a second (high) harmonic is to be used to cover the band's frequency range. \n
			:param freq_high: No help available
		"""
		param = Conversions.bool_to_str(freq_high)
		self._core.io.write(f'SENSe:MIXer:HARMonic:HIGH:STATe {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH:STATe \n
		Snippet: value: bool = driver.applications.k50Spurious.sense.mixer.harmonic.high.state.get() \n
		This command specifies whether a second (high) harmonic is to be used to cover the band's frequency range. \n
			:return: freq_high: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:HARMonic:HIGH:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class McCls:
	"""Mc commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mc", core, parent)

	@property
	def distance(self):
		"""distance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_distance'):
			from .Distance import DistanceCls
			self._distance = DistanceCls(self._core, self._cmd_group)
		return self._distance

	@property
	def cfrequency(self):
		"""cfrequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cfrequency'):
			from .Cfrequency import CfrequencyCls
			self._cfrequency = CfrequencyCls(self._core, self._cmd_group)
		return self._cfrequency

	@property
	def range(self):
		"""range commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	def clone(self) -> 'McCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = McCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def memory(self):
		"""memory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_memory'):
			from .Memory import MemoryCls
			self._memory = MemoryCls(self._core, self._cmd_group)
		return self._memory

	@property
	def memoryAll(self):
		"""memoryAll commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_memoryAll'):
			from .MemoryAll import MemoryAllCls
			self._memoryAll = MemoryAllCls(self._core, self._cmd_group)
		return self._memoryAll

	def get(self) -> List[float]:
		"""SCPI: TRACe:IQ:DATA \n
		Snippet: value: List[float] = driver.trace.iq.data.get() \n
		This command initiates a measurement with the current settings and returns the captured data from I/Q measurements. This
		command corresponds to: INIT:IMM;*WAI;method RsFswp.Trace.Iq.Data.Memory.get_ However, the method RsFswp.Trace.Iq.Data.
		get_ command is quicker in comparison. Note: Using the command with the *RST values for the TRACe:IQ:SET command, the
		following minimum buffer sizes for the response data are recommended: ASCII format 10 kBytes, binary format: 2 kBytes \n
			:return: iq_data: Measured voltage for I and Q component for each sample that has been captured during the measurement. The number of samples depends on TRACe:IQ:SET. In ASCII format, the number of results is 2* the number of samples. The data format depends on method RsFswp.Applications.IqAnalyzer.Trace.Iq.Data.FormatPy.set. Unit: V"""
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe:IQ:DATA?')
		return response

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReferenceCls:
	"""Reference commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("reference", core, parent)

	@property
	def meastoRef(self):
		"""meastoRef commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_meastoRef'):
			from .MeastoRef import MeastoRefCls
			self._meastoRef = MeastoRefCls(self._core, self._cmd_group)
		return self._meastoRef

	def set(self, ref_value: float, trace=repcap.Trace.Default) -> None:
		"""SCPI: CONFigure:ADEMod:RESults:AM:DETector<det>:REFerence \n
		Snippet: driver.configure.ademod.results.am.detector.reference.set(ref_value = 1.0, trace = repcap.Trace.Default) \n
		Defines the reference value to be used for relative demodulation results and recalculates the results. If necessary, the
		detector is activated. A reference value 0 would provide infinite results and is thus automatically corrected to 0.1. \n
			:param ref_value: double value The unit depends on the demodulation type: ACV: V AM: % FM: Hz PM: depends on method RsFswp.Unit.Angle.set setting Unit: RAD
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
		"""
		param = Conversions.decimal_value_to_str(ref_value)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CONFigure:ADEMod:RESults:AM:DETector{trace_cmd_val}:REFerence {param}')

	def get(self, trace=repcap.Trace.Default) -> float:
		"""SCPI: CONFigure:ADEMod:RESults:AM:DETector<det>:REFerence \n
		Snippet: value: float = driver.configure.ademod.results.am.detector.reference.get(trace = repcap.Trace.Default) \n
		Defines the reference value to be used for relative demodulation results and recalculates the results. If necessary, the
		detector is activated. A reference value 0 would provide infinite results and is thus automatically corrected to 0.1. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
			:return: ref_value: double value The unit depends on the demodulation type: ACV: V AM: % FM: Hz PM: depends on method RsFswp.Unit.Angle.set setting Unit: RAD"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CONFigure:ADEMod:RESults:AM:DETector{trace_cmd_val}:REFerence?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ReferenceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ReferenceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EndCls:
	"""End commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("end", core, parent)

	def set(self, time: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:HOPDetection:PNOise:OFFSet:END \n
		Snippet: driver.applications.k60Transient.calculate.hopDetection.pnoise.offset.end.set(time = 1.0, window = repcap.Window.Default) \n
		Defines the end of the measurement range for phase noise results as an offset in seconds from the hop end. This command
		is only available if the reference is EDGE (see method RsFswp.Applications.K60_Transient.Calculate.HopDetection.Pnoise.
		Reference.set) . \n
			:param time: Unit: S
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(time)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:HOPDetection:PNOise:OFFSet:END {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:HOPDetection:PNOise:OFFSet:END \n
		Snippet: value: float = driver.applications.k60Transient.calculate.hopDetection.pnoise.offset.end.get(window = repcap.Window.Default) \n
		Defines the end of the measurement range for phase noise results as an offset in seconds from the hop end. This command
		is only available if the reference is EDGE (see method RsFswp.Applications.K60_Transient.Calculate.HopDetection.Pnoise.
		Reference.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: time: Unit: S"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:HOPDetection:PNOise:OFFSet:END?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HighCls:
	"""High commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("high", core, parent)

	def set(self, loss_high: float) -> None:
		"""SCPI: [SENSe]:MIXer:LOSS:HIGH \n
		Snippet: driver.applications.k50Spurious.sense.mixer.loss.high.set(loss_high = 1.0) \n
		This command defines the average conversion loss to be used for the entire high (second) range. \n
			:param loss_high: No help available
		"""
		param = Conversions.decimal_value_to_str(loss_high)
		self._core.io.write(f'SENSe:MIXer:LOSS:HIGH {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MIXer:LOSS:HIGH \n
		Snippet: value: float = driver.applications.k50Spurious.sense.mixer.loss.high.get() \n
		This command defines the average conversion loss to be used for the entire high (second) range. \n
			:return: loss_high: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:LOSS:HIGH?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReplaceCls:
	"""Replace commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("replace", core, parent)

	def set(self, current_channel_name: str, channel_type: enums.ChannelType, new_channel_name: str) -> None:
		"""SCPI: INSTrument:CREate:REPLace \n
		Snippet: driver.instrument.create.replace.set(current_channel_name = '1', channel_type = enums.ChannelType.IqAnalyzer=IQ, new_channel_name = '1') \n
		This command replaces a channel with another one. \n
			:param current_channel_name: No help available
			:param channel_type: Channel type of the new channel. For a list of available channel types, see method RsFswp.Instrument.ListPy.get_.
			:param new_channel_name: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('current_channel_name', current_channel_name, DataType.String), ArgSingle('channel_type', channel_type, DataType.Enum, enums.ChannelType), ArgSingle('new_channel_name', new_channel_name, DataType.String))
		self._core.io.write_with_opc(f'INSTrument:CREate:REPLace {param}'.rstrip())
		self._core.io.write('INIT:CONT OFF')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, file_path: str, fileList=repcap.FileList.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:FLISt<fli>:SELect \n
		Snippet: driver.sense.correction.fresponse.user.flist.select.set(file_path = '1', fileList = repcap.FileList.Default) \n
		No command help available \n
			:param file_path: No help available
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
		"""
		param = Conversions.value_to_quoted_str(file_path)
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:FLISt{fileList_cmd_val}:SELect {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ServiceCls:
	"""Service commands group definition. 32 total commands, 12 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("service", core, parent)

	@property
	def date(self):
		"""date commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_date'):
			from .Date import DateCls
			self._date = DateCls(self._core, self._cmd_group)
		return self._date

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def calibration(self):
		"""calibration commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	@property
	def inputPy(self):
		"""inputPy commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def sfunction(self):
		"""sfunction commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfunction'):
			from .Sfunction import SfunctionCls
			self._sfunction = SfunctionCls(self._core, self._cmd_group)
		return self._sfunction

	@property
	def stest(self):
		"""stest commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_stest'):
			from .Stest import StestCls
			self._stest = StestCls(self._core, self._cmd_group)
		return self._stest

	@property
	def spCheck(self):
		"""spCheck commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_spCheck'):
			from .SpCheck import SpCheckCls
			self._spCheck = SpCheckCls(self._core, self._cmd_group)
		return self._spCheck

	@property
	def biosInfo(self):
		"""biosInfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_biosInfo'):
			from .BiosInfo import BiosInfoCls
			self._biosInfo = BiosInfoCls(self._core, self._cmd_group)
		return self._biosInfo

	@property
	def hwInfo(self):
		"""hwInfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hwInfo'):
			from .HwInfo import HwInfoCls
			self._hwInfo = HwInfoCls(self._core, self._cmd_group)
		return self._hwInfo

	@property
	def versionInfo(self):
		"""versionInfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_versionInfo'):
			from .VersionInfo import VersionInfoCls
			self._versionInfo = VersionInfoCls(self._core, self._cmd_group)
		return self._versionInfo

	@property
	def sinfo(self):
		"""sinfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sinfo'):
			from .Sinfo import SinfoCls
			self._sinfo = SinfoCls(self._core, self._cmd_group)
		return self._sinfo

	@property
	def nsource(self):
		"""nsource commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsource'):
			from .Nsource import NsourceCls
			self._nsource = NsourceCls(self._core, self._cmd_group)
		return self._nsource

	def clone(self) -> 'ServiceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ServiceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EgateCls:
	"""Egate commands group definition. 11 total commands, 8 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("egate", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def level(self):
		"""level commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def polarity(self):
		"""polarity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_polarity'):
			from .Polarity import PolarityCls
			self._polarity = PolarityCls(self._core, self._cmd_group)
		return self._polarity

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def holdoff(self):
		"""holdoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_holdoff'):
			from .Holdoff import HoldoffCls
			self._holdoff = HoldoffCls(self._core, self._cmd_group)
		return self._holdoff

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def continuous(self):
		"""continuous commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_continuous'):
			from .Continuous import ContinuousCls
			self._continuous = ContinuousCls(self._core, self._cmd_group)
		return self._continuous

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe \n
		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.set(state = False) \n
		This command turns gated measurements on and off. See '(Measurement) Points'. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:SWEep:EGATe {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:SWEep:EGATe \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.sense.sweep.egate.get() \n
		This command turns gated measurements on and off. See '(Measurement) Points'. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'EgateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EgateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UaRangeCls:
	"""UaRange commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uaRange", core, parent)

	def set(self, param: enums.RangeParam, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:UARange \n
		Snippet: driver.applications.k50Spurious.sense.listPy.range.uaRange.set(param = enums.RangeParam.ARBW, rangePy = repcap.RangePy.Default) \n
		Writes the value of the specified parameter to all of the currently defined ranges. \n
			:param param: ARBW | LOFFset | MFRBw | NFFT | PAValue | PEXCursion | RBW | RFATtenuation | RLEVel | SNRatio | TSTR | TSTP
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.enum_scalar_to_str(param, enums.RangeParam)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:UARange {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, fine_sync: enums.FineSync) -> None:
		"""SCPI: [SENSe]:DDEMod:FSYNc[:MODE] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.fsync.mode.set(fine_sync = enums.FineSync.DDATa) \n
		This command defines the fine synchronization mode used to calculate results, e.g. the bit error rate. Note:You can
		define a maximum symbol error rate (SER) for the known data in reference to the analyzed data. If the SER of the known
		data exceeds this limit, the default synchronization using the detected data is performed. See [SENSe:]DDEMod:FSYNc:LEVel. \n
			:param fine_sync: KDATa | PATTern | DDATa KDATa (Default) The reference signal is defined as the data sequence from the loaded Known Data file that most closely matches the measured data. PATTern The reference signal is estimated from the defined pattern. This setting requires an activated pattern search, see [SENSe:]DDEMod:SEARch:SYNC:STATe. DDATa The reference signal is estimated from the detected data.
		"""
		param = Conversions.enum_scalar_to_str(fine_sync, enums.FineSync)
		self._core.io.write(f'SENSe:DDEMod:FSYNc:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FineSync:
		"""SCPI: [SENSe]:DDEMod:FSYNc[:MODE] \n
		Snippet: value: enums.FineSync = driver.applications.k70Vsa.sense.ddemod.fsync.mode.get() \n
		This command defines the fine synchronization mode used to calculate results, e.g. the bit error rate. Note:You can
		define a maximum symbol error rate (SER) for the known data in reference to the analyzed data. If the SER of the known
		data exceeds this limit, the default synchronization using the detected data is performed. See [SENSe:]DDEMod:FSYNc:LEVel. \n
			:return: fine_sync: KDATa | PATTern | DDATa KDATa (Default) The reference signal is defined as the data sequence from the loaded Known Data file that most closely matches the measured data. PATTern The reference signal is estimated from the defined pattern. This setting requires an activated pattern search, see [SENSe:]DDEMod:SEARch:SYNC:STATe. DDATa The reference signal is estimated from the detected data."""
		response = self._core.io.query_str(f'SENSe:DDEMod:FSYNc:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FineSync)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.LoadType) -> None:
		"""SCPI: MMEMory:LOAD:TYPE \n
		Snippet: driver.massMemory.load.typePy.set(type_py = enums.LoadType.NEW) \n
		No command help available \n
			:param type_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.LoadType)
		self._core.io.write(f'MMEMory:LOAD:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.LoadType:
		"""SCPI: MMEMory:LOAD:TYPE \n
		Snippet: value: enums.LoadType = driver.massMemory.load.typePy.get() \n
		No command help available \n
			:return: type_py: No help available"""
		response = self._core.io.query_str(f'MMEMory:LOAD:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.LoadType)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UnitCls:
	"""Unit commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("unit", core, parent)

	def set(self, arg_0: enums.DiqUnit) -> None:
		"""SCPI: INPut:DIQ:RANGe[:UPPer]:UNIT \n
		Snippet: driver.inputPy.diq.range.upper.unit.set(arg_0 = enums.DiqUnit.AMPere) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.DiqUnit)
		self._core.io.write(f'INPut:DIQ:RANGe:UPPer:UNIT {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DiqUnit:
		"""SCPI: INPut:DIQ:RANGe[:UPPer]:UNIT \n
		Snippet: value: enums.DiqUnit = driver.inputPy.diq.range.upper.unit.get() \n
		No command help available \n
			:return: arg_0: No help available"""
		response = self._core.io.query_str(f'INPut:DIQ:RANGe:UPPer:UNIT?')
		return Conversions.str_to_scalar_enum(response, enums.DiqUnit)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def set(self, unit: enums.PowerUnitB, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:UNIT:POWer \n
		Snippet: driver.calculate.unit.power.set(unit = enums.PowerUnitB.A, window = repcap.Window.Default) \n
		This command selects the unit of the y-axis. The unit applies to all power-based measurement windows with absolute values. \n
			:param unit: DBM | V | A | W | DBPW | WATT | DBUV | DBMV | VOLT | DBUA | AMPere
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.PowerUnitB)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:UNIT:POWer {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.PowerUnitB:
		"""SCPI: CALCulate<n>:UNIT:POWer \n
		Snippet: value: enums.PowerUnitB = driver.calculate.unit.power.get(window = repcap.Window.Default) \n
		This command selects the unit of the y-axis. The unit applies to all power-based measurement windows with absolute values. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: unit: DBM | V | A | W | DBPW | WATT | DBUV | DBMV | VOLT | DBUA | AMPere"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNIT:POWer?')
		return Conversions.str_to_scalar_enum(response, enums.PowerUnitB)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PositionCls:
	"""Position commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("position", core, parent)

	def set(self, position: enums.DisplayPosition) -> None:
		"""SCPI: DISPlay:PRESelector:POSition \n
		Snippet: driver.display.preSelector.position.set(position = enums.DisplayPosition.BOTTom) \n
		No command help available \n
			:param position: No help available
		"""
		param = Conversions.enum_scalar_to_str(position, enums.DisplayPosition)
		self._core.io.write(f'DISPlay:PRESelector:POSition {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DisplayPosition:
		"""SCPI: DISPlay:PRESelector:POSition \n
		Snippet: value: enums.DisplayPosition = driver.display.preSelector.position.get() \n
		No command help available \n
			:return: position: No help available"""
		response = self._core.io.query_str(f'DISPlay:PRESelector:POSition?')
		return Conversions.str_to_scalar_enum(response, enums.DisplayPosition)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MsrCls:
	"""Msr commands group definition. 9 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("msr", core, parent)

	@property
	def rfbWidth(self):
		"""rfbWidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfbWidth'):
			from .RfbWidth import RfbWidthCls
			self._rfbWidth = RfbWidthCls(self._core, self._cmd_group)
		return self._rfbWidth

	@property
	def bcategory(self):
		"""bcategory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bcategory'):
			from .Bcategory import BcategoryCls
			self._bcategory = BcategoryCls(self._core, self._cmd_group)
		return self._bcategory

	@property
	def mpower(self):
		"""mpower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mpower'):
			from .Mpower import MpowerCls
			self._mpower = MpowerCls(self._core, self._cmd_group)
		return self._mpower

	@property
	def classPy(self):
		"""classPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_classPy'):
			from .ClassPy import ClassPyCls
			self._classPy = ClassPyCls(self._core, self._cmd_group)
		return self._classPy

	@property
	def band(self):
		"""band commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_band'):
			from .Band import BandCls
			self._band = BandCls(self._core, self._cmd_group)
		return self._band

	@property
	def gsm(self):
		"""gsm commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_gsm'):
			from .Gsm import GsmCls
			self._gsm = GsmCls(self._core, self._cmd_group)
		return self._gsm

	@property
	def lte(self):
		"""lte commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_lte'):
			from .Lte import LteCls
			self._lte = LteCls(self._core, self._cmd_group)
		return self._lte

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import ApplyCls
			self._apply = ApplyCls(self._core, self._cmd_group)
		return self._apply

	def clone(self) -> 'MsrCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MsrCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DemodCls:
	"""Demod commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("demod", core, parent)

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:BWIDth:DEMod \n
		Snippet: driver.sense.bandwidth.demod.set(bandwidth = 1.0) \n
		This command sets the bandwidth for Analog Modulation Analysis. Depending on the selected demodulation bandwidth, the
		instrument selects the required sample rate. This command is identical to SENS:ADEM:BAND:DEM. \n
			:param bandwidth: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:BWIDth:DEMod {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:BWIDth:DEMod \n
		Snippet: value: float = driver.sense.bandwidth.demod.get() \n
		This command sets the bandwidth for Analog Modulation Analysis. Depending on the selected demodulation bandwidth, the
		instrument selects the required sample rate. This command is identical to SENS:ADEM:BAND:DEM. \n
			:return: bandwidth: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:BWIDth:DEMod?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'DemodCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DemodCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	def set(self, dev_name: str, arg_1: bool) -> None:
		"""SCPI: [SENSe]:SAMPling:CLKio:OUTPut \n
		Snippet: driver.sense.sampling.clkio.output.set(dev_name = '1', arg_1 = False) \n
		No command help available \n
			:param dev_name: No help available
			:param arg_1: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('dev_name', dev_name, DataType.String), ArgSingle('arg_1', arg_1, DataType.Boolean))
		self._core.io.write(f'SENSe:SAMPling:CLKio:OUTPut {param}'.rstrip())

	def get(self) -> bool:
		"""SCPI: [SENSe]:SAMPling:CLKio:OUTPut \n
		Snippet: value: bool = driver.sense.sampling.clkio.output.get() \n
		No command help available \n
			:return: arg_1: No help available"""
		response = self._core.io.query_str(f'SENSe:SAMPling:CLKio:OUTPut?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolsCls:
	"""Symbols commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbols", core, parent)

	def set(self, symbol_selection: enums.SymbolSelection, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: CALCulate<n>:TRACe<t>:SYMBols \n
		Snippet: driver.applications.k70Vsa.calculate.trace.symbols.set(symbol_selection = enums.SymbolSelection.ALL, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This commands selects which symbols are displayed by a trace (in a constellation graph with 2 modulations) . For method
		RsFswp.Display.Window.Subwindow.Trace.Mode.set View, the symbol selection cannot be changed. It remains set to the value
		that was most recently set. \n
			:param symbol_selection: ALL | PATTern | DATA ALL Trace consists of constellation points for all symbols PATTern Trace consists of only pattern symbols DATA Trace consists of only data symbols
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(symbol_selection, enums.SymbolSelection)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:SYMBols {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.SymbolSelection:
		"""SCPI: CALCulate<n>:TRACe<t>:SYMBols \n
		Snippet: value: enums.SymbolSelection = driver.applications.k70Vsa.calculate.trace.symbols.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This commands selects which symbols are displayed by a trace (in a constellation graph with 2 modulations) . For method
		RsFswp.Display.Window.Subwindow.Trace.Mode.set View, the symbol selection cannot be changed. It remains set to the value
		that was most recently set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: symbol_selection: ALL | PATTern | DATA ALL Trace consists of constellation points for all symbols PATTern Trace consists of only pattern symbols DATA Trace consists of only data symbols"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:SYMBols?')
		return Conversions.str_to_scalar_enum(response, enums.SymbolSelection)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RoscillatorCls:
	"""Roscillator commands group definition. 12 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("roscillator", core, parent)

	@property
	def o100(self):
		"""o100 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_o100'):
			from .O100 import O100Cls
			self._o100 = O100Cls(self._core, self._cmd_group)
		return self._o100

	@property
	def o640(self):
		"""o640 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_o640'):
			from .O640 import O640Cls
			self._o640 = O640Cls(self._core, self._cmd_group)
		return self._o640

	@property
	def source(self):
		"""source commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	@property
	def trange(self):
		"""trange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trange'):
			from .Trange import TrangeCls
			self._trange = TrangeCls(self._core, self._cmd_group)
		return self._trange

	@property
	def lbWidth(self):
		"""lbWidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lbWidth'):
			from .LbWidth import LbWidthCls
			self._lbWidth = LbWidthCls(self._core, self._cmd_group)
		return self._lbWidth

	@property
	def osync(self):
		"""osync commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_osync'):
			from .Osync import OsyncCls
			self._osync = OsyncCls(self._core, self._cmd_group)
		return self._osync

	@property
	def coupling(self):
		"""coupling commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_coupling'):
			from .Coupling import CouplingCls
			self._coupling = CouplingCls(self._core, self._cmd_group)
		return self._coupling

	@property
	def output(self):
		"""output commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def passThrough(self):
		"""passThrough commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_passThrough'):
			from .PassThrough import PassThroughCls
			self._passThrough = PassThroughCls(self._core, self._cmd_group)
		return self._passThrough

	def clone(self) -> 'RoscillatorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RoscillatorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, trace_mode: List[enums.TraceModeA]) -> None:
		"""SCPI: [SENSe]:ADEMod:SPECtrum[:TYPE] \n
		Snippet: driver.sense.ademod.spectrum.typePy.set(trace_mode = [TraceModeA.AVERage, TraceModeA.WRITe]) \n
		This command selects the trace modes of the evaluated signal to be measured simultaneously. For each of the six available
		traces a mode can be defined. For details on trace modes see 'Mode'. The trace modes are configured identically for all
		windows with a specific evaluation. The following table indicates which command syntax refers to which evaluation method.
			Table Header: Command syntax / Evaluation method \n
			- AM[:ABSolute][:TDOMain] / RF time domain
			- AM:RELative[:TDOMain] / AM time domain
			- AM:RELative:AFSPectrum / AM spectrum (relative)
			- FM[:TDOMain] / FM time domain
			- FM:AFSPectrum / FM spectrum
			- PM[:TDOMain] / PM time domain
			- PM:AFSPectrum / PM spectrum
			- SPECtrum / RF spectrum \n
			:param trace_mode: WRITe | AVERage | MAXHold | MINHold | VIEW | OFF WRITe Overwrite mode: the trace is overwritten by each sweep. This is the default setting. AVERage The average is formed over several sweeps. MAXHold The maximum value is determined over several sweeps and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is greater than the previous one. MINHold The minimum value is determined from several measurements and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is lower than the previous one. VIEW The current contents of the trace memory are frozen and displayed. OFF Hides the selected trace.
		"""
		param = Conversions.enum_list_to_str(trace_mode, enums.TraceModeA)
		self._core.io.write(f'SENSe:ADEMod:SPECtrum:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> List[enums.TraceModeA]:
		"""SCPI: [SENSe]:ADEMod:SPECtrum[:TYPE] \n
		Snippet: value: List[enums.TraceModeA] = driver.sense.ademod.spectrum.typePy.get() \n
		This command selects the trace modes of the evaluated signal to be measured simultaneously. For each of the six available
		traces a mode can be defined. For details on trace modes see 'Mode'. The trace modes are configured identically for all
		windows with a specific evaluation. The following table indicates which command syntax refers to which evaluation method.
			Table Header: Command syntax / Evaluation method \n
			- AM[:ABSolute][:TDOMain] / RF time domain
			- AM:RELative[:TDOMain] / AM time domain
			- AM:RELative:AFSPectrum / AM spectrum (relative)
			- FM[:TDOMain] / FM time domain
			- FM:AFSPectrum / FM spectrum
			- PM[:TDOMain] / PM time domain
			- PM:AFSPectrum / PM spectrum
			- SPECtrum / RF spectrum \n
			:return: trace_mode: WRITe | AVERage | MAXHold | MINHold | VIEW | OFF WRITe Overwrite mode: the trace is overwritten by each sweep. This is the default setting. AVERage The average is formed over several sweeps. MAXHold The maximum value is determined over several sweeps and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is greater than the previous one. MINHold The minimum value is determined from several measurements and displayed. The R&S FSWP saves the sweep result in the trace memory only if the new value is lower than the previous one. VIEW The current contents of the trace memory are frozen and displayed. OFF Hides the selected trace."""
		response = self._core.io.query_str(f'SENSe:ADEMod:SPECtrum:TYPE?')
		return Conversions.str_to_list_enum(response, enums.TraceModeA)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BitErrorRateCls:
	"""BitErrorRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bitErrorRate", core, parent)

	def get(self, format_py: enums.BerRateFormat, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:BERate \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.bitErrorRate.get(format_py = enums.BerRateFormat.CURRent, window = repcap.Window.Default) \n
		Queries the Bit Error Rate results. The available results are described in 'Bit error rate (BER) '.
		Note that the specified window suffix must refer to a BER result display. \n
			:param format_py: Specifies a particular BER result to be queried. If no parameter is specified, the current bit error rate is returned. The parameters for these results are listed in Table 'Parameters for BER result values'. DSINdex Queries the index of the identified data sequence found in a known data file. The index starts with 0, that is: the first data sequence in the file is returned as '0'.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: results: No help available"""
		param = Conversions.enum_scalar_to_str(format_py, enums.BerRateFormat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str_with_opc(f'CALCulate{window_cmd_val}:BERate? {param}')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class K50_SpuriousCls:
	"""K50_Spurious commands group definition. 235 total commands, 16 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("k50_Spurious", core, parent)

	@property
	def layout(self):
		"""layout commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_layout'):
			from .Layout import LayoutCls
			self._layout = LayoutCls(self._core, self._cmd_group)
		return self._layout

	@property
	def trace(self):
		"""trace commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def triggerInvoke(self):
		"""triggerInvoke commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_triggerInvoke'):
			from .TriggerInvoke import TriggerInvokeCls
			self._triggerInvoke = TriggerInvokeCls(self._core, self._cmd_group)
		return self._triggerInvoke

	@property
	def calculate(self):
		"""calculate commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_calculate'):
			from .Calculate import CalculateCls
			self._calculate = CalculateCls(self._core, self._cmd_group)
		return self._calculate

	@property
	def display(self):
		"""display commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_display'):
			from .Display import DisplayCls
			self._display = DisplayCls(self._core, self._cmd_group)
		return self._display

	@property
	def formatPy(self):
		"""formatPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def inputPy(self):
		"""inputPy commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def initiate(self):
		"""initiate commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_initiate'):
			from .Initiate import InitiateCls
			self._initiate = InitiateCls(self._core, self._cmd_group)
		return self._initiate

	@property
	def massMemory(self):
		"""massMemory commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_massMemory'):
			from .MassMemory import MassMemoryCls
			self._massMemory = MassMemoryCls(self._core, self._cmd_group)
		return self._massMemory

	@property
	def output(self):
		"""output commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def sense(self):
		"""sense commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_sense'):
			from .Sense import SenseCls
			self._sense = SenseCls(self._core, self._cmd_group)
		return self._sense

	@property
	def trigger(self):
		"""trigger commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def calibration(self):
		"""calibration commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	@property
	def fetch(self):
		"""fetch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fetch'):
			from .Fetch import FetchCls
			self._fetch = FetchCls(self._core, self._cmd_group)
		return self._fetch

	@property
	def read(self):
		"""read commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_read'):
			from .Read import ReadCls
			self._read = ReadCls(self._core, self._cmd_group)
		return self._read

	@property
	def unit(self):
		"""unit commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_unit'):
			from .Unit import UnitCls
			self._unit = UnitCls(self._core, self._cmd_group)
		return self._unit

	def clone(self) -> 'K50_SpuriousCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = K50_SpuriousCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MagnitudeCls:
	"""Magnitude commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("magnitude", core, parent)

	def get(self) -> List[float]:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SPECtrum:DATA:MAGNitude \n
		Snippet: value: List[float] = driver.sense.correction.fresponse.user.spectrum.data.magnitude.get() \n
		No command help available \n
			:return: trace_data: No help available"""
		response = self._core.io.query_bin_or_ascii_float_list_with_opc(f'FORMAT REAL,32;SENSe:CORRection:FRESponse:USER:SPECtrum:DATA:MAGNitude?')
		return response



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfErrorCls:
	"""CfError commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfError", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:CFERror \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.cfError.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the carrier frequency error measurement performed for digital demodulation.
		The output values are the same as those provided in the 'Modulation Accuracy' table. \n
			:param result_type: none Carrier frequency error for current sweep AVG Average carrier frequency error over several sweeps RPE Peak carrier frequency error over several sweeps SDEV Standard deviation of frequency error PCTL 95 percentile value of frequency error
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:CFERror? {param}')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> int:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:STARt \n
		Snippet: value: int = driver.applications.k70Vsa.display.window.trace.x.scale.start.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command queries the first value of the x-axis in the specified window in symbols or time, depending on the unit
		setting for the x-axis. Note: using the method RsFswp.Applications.K70_Vsa.Calculate.Trace.Adjust.Alignment.Offset.
		set command, the burst is shifted in the diagram; the x-axis thus no longer begins on the left at 0 symbols but at a
		selectable value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: start: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:STARt?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MerrorCls:
	"""Merror commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("merror", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:MERRor \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.merror.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the magnitude error measurement of digital demodulation. \n
			:param result_type: none RMS magnitude error of display points of current sweep AVG Average of magnitude errors over several sweeps PAVG Average of maximum magnitude errors over several sweeps PCTL 95% percentile of magnitude error over several sweeps PEAK Maximum magnitude errors over all symbols of current sweep PPCT 95% percentile of maximum magnitude errors over several sweeps PSD Standard deviation of maximum magnitude errors over several sweeps RPE Maximum value of magnitude errors over several sweeps SDEV Standard deviation of magnitude errors over several sweeps TPE Maximum magnitude errors over all display points over several sweeps
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:MERRor? {param}')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, est_oversampling: float) -> None:
		"""SCPI: [SENSe]:DDEMod:EPRate[:VALue] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.epRate.value.set(est_oversampling = 1.0) \n
		Defines how many sample points are used at each symbol to calculate modulation accuracy results. For more information see
		'Estimation points per symbol'. You can also let the VSA application decide how many estimation points to use, see
		[SENSe:]DDEMod:EPRate:AUTO. \n
			:param est_oversampling: 1 the estimation algorithm takes only the symbol time instants into account 2 two points per symbol instant are used (required for Offset QPSK) 4 | 8 | 16 | 32 the number of samples per symbol defined in the signal capture settings is used (see [SENSe:]DDEMod:PRATe) , i.e. all sample time instants are weighted equally
		"""
		param = Conversions.decimal_value_to_str(est_oversampling)
		self._core.io.write(f'SENSe:DDEMod:EPRate:VALue {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:EPRate[:VALue] \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.epRate.value.get() \n
		Defines how many sample points are used at each symbol to calculate modulation accuracy results. For more information see
		'Estimation points per symbol'. You can also let the VSA application decide how many estimation points to use, see
		[SENSe:]DDEMod:EPRate:AUTO. \n
			:return: est_oversampling: 1 the estimation algorithm takes only the symbol time instants into account 2 two points per symbol instant are used (required for Offset QPSK) 4 | 8 | 16 | 32 the number of samples per symbol defined in the signal capture settings is used (see [SENSe:]DDEMod:PRATe) , i.e. all sample time instants are weighted equally"""
		response = self._core.io.query_str(f'SENSe:DDEMod:EPRate:VALue?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RefMeasCls:
	"""RefMeas commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("refMeas", core, parent)

	def set(self) -> None:
		"""SCPI: INITiate:REFMeas \n
		Snippet: driver.applications.k70Vsa.initiate.refMeas.set() \n
		Repeats the evaluation of the data currently in the capture buffer without capturing new data. This is useful for long
		capture buffers that are split into sections for result displays. In this case, only the data in the currently selected
		capture buffer section is automatically refreshed after configuration changes. To update the entire capture buffer, you
		must refresh the evaluation manually using this command. See also 'Capture buffer display'. \n
		"""
		self._core.io.write(f'INITiate:REFMeas')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INITiate:REFMeas \n
		Snippet: driver.applications.k70Vsa.initiate.refMeas.set_with_opc() \n
		Repeats the evaluation of the data currently in the capture buffer without capturing new data. This is useful for long
		capture buffers that are split into sections for result displays. In this case, only the data in the currently selected
		capture buffer section is automatically refreshed after configuration changes. To update the entire capture buffer, you
		must refresh the evaluation manually using this command. See also 'Capture buffer display'. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INITiate:REFMeas', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:STATe \n
		Snippet: driver.applications.k70Vsa.display.window.state.set(state = False, window = repcap.Window.Default) \n
		Activates or deactivates the specified window. Note that this command is maintained for compatibility reasons only. Use
		the LAYout commands for new remote control programs (see 'Working with windows in the display') . \n
			:param state: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:STATe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>]:STATe \n
		Snippet: value: bool = driver.applications.k70Vsa.display.window.state.get(window = repcap.Window.Default) \n
		Activates or deactivates the specified window. Note that this command is maintained for compatibility reasons only. Use
		the LAYout commands for new remote control programs (see 'Working with windows in the display') . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: state: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfdriftCls:
	"""Cfdrift commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfdrift", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:FSK:CFDRift \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.fsk.cfdrift.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the carrier frequency drift for FSK modulated signals. \n
			:param result_type: none Carrier frequency drift for current sweep. AVG Average FSK carrier frequency drift over several sweeps. RPE Peak FSK carrier frequency drift over several sweeps. SDEV Standard deviation of FSK carrier frequency drift. PCTL 95 percentile value of FSK carrier frequency drift.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:FSK:CFDRift? {param}')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, value: str, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:UPORt[:VALue] \n
		Snippet: driver.output.uport.value.set(value = r1, outputConnector = repcap.OutputConnector.Default) \n
		This command sets the control lines of the user ports. The assignment of the pin numbers to the bits is as follows:
			Table Header: Bit / 7 / 6 / 5 / 4 / 3 / 2 / 1 / 0 \n
			- Pin / N/A / N/A / 5 / 3 / 4 / 7 / 6 / 2
		Bits 7 and 6 are not assigned to pins and must always be 0. The user port is written to with the given binary pattern. If
		the user port is programmed to input instead of output (see method RsFswp.InputPy.Uport.State.set) , the output value is
		temporarily stored. \n
			:param value: bit values in hexadecimal format TTL type voltage levels (max. 5V) Range: #B00000000 to #B00111111
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.value_to_str(value)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:UPORt:VALue {param}')

	def get(self, outputConnector=repcap.OutputConnector.Default) -> str:
		"""SCPI: OUTPut<up>:UPORt[:VALue] \n
		Snippet: value: str = driver.output.uport.value.get(outputConnector = repcap.OutputConnector.Default) \n
		This command sets the control lines of the user ports. The assignment of the pin numbers to the bits is as follows:
			Table Header: Bit / 7 / 6 / 5 / 4 / 3 / 2 / 1 / 0 \n
			- Pin / N/A / N/A / 5 / 3 / 4 / 7 / 6 / 2
		Bits 7 and 6 are not assigned to pins and must always be 0. The user port is written to with the given binary pattern. If
		the user port is programmed to input instead of output (see method RsFswp.InputPy.Uport.State.set) , the output value is
		temporarily stored. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: value: bit values in hexadecimal format TTL type voltage levels (max. 5V) Range: #B00000000 to #B00111111"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:UPORt:VALue?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfErrorCls:
	"""CfError commands group definition. 9 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfError", core, parent)

	@property
	def current(self):
		"""current commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_current'):
			from .Current import CurrentCls
			self._current = CurrentCls(self._core, self._cmd_group)
		return self._current

	@property
	def mean(self):
		"""mean commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mean'):
			from .Mean import MeanCls
			self._mean = MeanCls(self._core, self._cmd_group)
		return self._mean

	@property
	def peak(self):
		"""peak commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_peak'):
			from .Peak import PeakCls
			self._peak = PeakCls(self._core, self._cmd_group)
		return self._peak

	def clone(self) -> 'CfErrorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CfErrorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CenterCls:
	"""Center commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("center", core, parent)

	def set(self, frequency: float, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:FREQuency:CENTer \n
		Snippet: driver.sense.power.achannel.sblock.frequency.center.set(frequency = 1.0, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param frequency: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:FREQuency:CENTer {param}')

	def get(self, subBlock=repcap.SubBlock.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:FREQuency:CENTer \n
		Snippet: value: float = driver.sense.power.achannel.sblock.frequency.center.get(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
			:return: frequency: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:FREQuency:CENTer?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, coupling: enums.PmeterFreqLink, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:FREQuency:LINK \n
		Snippet: driver.sense.pmeter.frequency.link.set(coupling = enums.PmeterFreqLink.CENTer, powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param coupling: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.enum_scalar_to_str(coupling, enums.PmeterFreqLink)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:FREQuency:LINK {param}')

	# noinspection PyTypeChecker
	def get(self, powerMeter=repcap.PowerMeter.Default) -> enums.PmeterFreqLink:
		"""SCPI: [SENSe]:PMETer<p>:FREQuency:LINK \n
		Snippet: value: enums.PmeterFreqLink = driver.sense.pmeter.frequency.link.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: coupling: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:FREQuency:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.PmeterFreqLink)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpectrogramCls:
	"""Spectrogram commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spectrogram", core, parent)

	def set(self, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:SPECtrogram \n
		Snippet: driver.massMemory.store.spectrogram.set(filename = '1', store = repcap.Store.Default) \n
		No command help available \n
			:param filename: No help available
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = Conversions.value_to_quoted_str(filename)
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:SPECtrogram {param}')

	def get(self, store=repcap.Store.Default) -> str:
		"""SCPI: MMEMory:STORe<n>:SPECtrogram \n
		Snippet: value: str = driver.massMemory.store.spectrogram.get(store = repcap.Store.Default) \n
		No command help available \n
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
			:return: filename: No help available"""
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		response = self._core.io.query_str(f'MMEMory:STORe{store_cmd_val}:SPECtrogram?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TemperatureCls:
	"""Temperature commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("temperature", core, parent)

	def set(self, temperature: float) -> None:
		"""SCPI: [SENSe]:CORRection:LOSS:CALibration:TEMPerature \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.loss.calibration.temperature.set(temperature = 1.0) \n
		The specified temperature at the time of measurement is considered in the loss calculation. \n
			:param temperature: Unit: K
		"""
		param = Conversions.decimal_value_to_str(temperature)
		self._core.io.write(f'SENSe:CORRection:LOSS:CALibration:TEMPerature {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:LOSS:CALibration:TEMPerature \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.correction.loss.calibration.temperature.get() \n
		The specified temperature at the time of measurement is considered in the loss calculation. \n
			:return: temperature: Unit: K"""
		response = self._core.io.query_str(f'SENSe:CORRection:LOSS:CALibration:TEMPerature?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InsertCls:
	"""Insert commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("insert", core, parent)

	def set(self, direction: enums.LeftRightDirection, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:INSert \n
		Snippet: driver.applications.k50Spurious.sense.listPy.range.insert.set(direction = enums.LeftRightDirection.LEFT, rangePy = repcap.RangePy.Default) \n
		Adds a range right or left to the selected one. If the command is used on a range that does not yet exist, the range and
		all with lower indices up to this one are created. \n
			:param direction: LEFT | RIGHt
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.LeftRightDirection)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:INSert {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CommentCls:
	"""Comment commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("comment", core, parent)

	def set(self, comment: str) -> None:
		"""SCPI: MMEMory:COMMent \n
		Snippet: driver.massMemory.comment.set(comment = '1') \n
		This command defines a comment for the stored settings. \n
			:param comment: String containing the comment.
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'MMEMory:COMMent {param}')

	def get(self) -> str:
		"""SCPI: MMEMory:COMMent \n
		Snippet: value: str = driver.massMemory.comment.get() \n
		This command defines a comment for the stored settings. \n
			:return: comment: String containing the comment."""
		response = self._core.io.query_str(f'MMEMory:COMMent?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FftCls:
	"""Fft commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fft", core, parent)

	def set(self, filter_mode: enums.FftFilterMode) -> None:
		"""SCPI: [SENSe]:BWIDth[:RESolution]:FFT \n
		Snippet: driver.sense.bandwidth.resolution.fft.set(filter_mode = enums.FftFilterMode.AUTO) \n
		No command help available \n
			:param filter_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(filter_mode, enums.FftFilterMode)
		self._core.io.write(f'SENSe:BWIDth:RESolution:FFT {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FftFilterMode:
		"""SCPI: [SENSe]:BWIDth[:RESolution]:FFT \n
		Snippet: value: enums.FftFilterMode = driver.sense.bandwidth.resolution.fft.get() \n
		No command help available \n
			:return: filter_mode: No help available"""
		response = self._core.io.query_str(f'SENSe:BWIDth:RESolution:FFT?')
		return Conversions.str_to_scalar_enum(response, enums.FftFilterMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TriggerCls:
	"""Trigger commands group definition. 6 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def hysteresis(self):
		"""hysteresis commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hysteresis'):
			from .Hysteresis import HysteresisCls
			self._hysteresis = HysteresisCls(self._core, self._cmd_group)
		return self._hysteresis

	@property
	def holdoff(self):
		"""holdoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_holdoff'):
			from .Holdoff import HoldoffCls
			self._holdoff = HoldoffCls(self._core, self._cmd_group)
		return self._holdoff

	@property
	def dtime(self):
		"""dtime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dtime'):
			from .Dtime import DtimeCls
			self._dtime = DtimeCls(self._core, self._cmd_group)
		return self._dtime

	@property
	def slope(self):
		"""slope commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slope'):
			from .Slope import SlopeCls
			self._slope = SlopeCls(self._core, self._cmd_group)
		return self._slope

	def clone(self) -> 'TriggerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TriggerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CompatibleCls:
	"""Compatible commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("compatible", core, parent)

	def set(self, arg_0: enums.PresetCompatible) -> None:
		"""SCPI: SYSTem:PRESet:COMPatible \n
		Snippet: driver.system.preset.compatible.set(arg_0 = enums.PresetCompatible.MRECeiver) \n
		This command defines the operating mode that is activated when you switch on the R&S FSWP or press the [PRESET] key. \n
			:param arg_0: SANalyzer Defines Signal and Spectrum Analyzer operating mode as the presetting. OFF Selects the phase noise application as the default application (default value) .
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.PresetCompatible)
		self._core.io.write(f'SYSTem:PRESet:COMPatible {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PresetCompatible:
		"""SCPI: SYSTem:PRESet:COMPatible \n
		Snippet: value: enums.PresetCompatible = driver.system.preset.compatible.get() \n
		This command defines the operating mode that is activated when you switch on the R&S FSWP or press the [PRESET] key. \n
			:return: arg_0: No help available"""
		response = self._core.io.query_str(f'SYSTem:PRESet:COMPatible?')
		return Conversions.str_to_scalar_enum(response, enums.PresetCompatible)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 10 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def achannel(self):
		"""achannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_achannel'):
			from .Achannel import AchannelCls
			self._achannel = AchannelCls(self._core, self._cmd_group)
		return self._achannel

	@property
	def uaChannel(self):
		"""uaChannel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uaChannel'):
			from .UaChannel import UaChannelCls
			self._uaChannel = UaChannelCls(self._core, self._cmd_group)
		return self._uaChannel

	@property
	def alternate(self):
		"""alternate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alternate'):
			from .Alternate import AlternateCls
			self._alternate = AlternateCls(self._core, self._cmd_group)
		return self._alternate

	@property
	def ualternate(self):
		"""ualternate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ualternate'):
			from .Ualternate import UalternateCls
			self._ualternate = UalternateCls(self._core, self._cmd_group)
		return self._ualternate

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import ChannelCls
			self._channel = ChannelCls(self._core, self._cmd_group)
		return self._channel

	@property
	def sblock(self):
		"""sblock commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sblock'):
			from .Sblock import SblockCls
			self._sblock = SblockCls(self._core, self._cmd_group)
		return self._sblock

	@property
	def gap(self):
		"""gap commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_gap'):
			from .Gap import GapCls
			self._gap = GapCls(self._core, self._cmd_group)
		return self._gap

	def clone(self) -> 'StateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 45 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def current(self):
		"""current commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_current'):
			from .Current import CurrentCls
			self._current = CurrentCls(self._core, self._cmd_group)
		return self._current

	@property
	def generator(self):
		"""generator commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_generator'):
			from .Generator import GeneratorCls
			self._generator = GeneratorCls(self._core, self._cmd_group)
		return self._generator

	@property
	def power(self):
		"""power commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def voltage(self):
		"""voltage commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_voltage'):
			from .Voltage import VoltageCls
			self._voltage = VoltageCls(self._core, self._cmd_group)
		return self._voltage

	@property
	def external(self):
		"""external commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_external'):
			from .External import ExternalCls
			self._external = ExternalCls(self._core, self._cmd_group)
		return self._external

	@property
	def temperature(self):
		"""temperature commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_temperature'):
			from .Temperature import TemperatureCls
			self._temperature = TemperatureCls(self._core, self._cmd_group)
		return self._temperature

	def clone(self) -> 'SourceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SourceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ToleranceCls:
	"""Tolerance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tolerance", core, parent)

	def set(self, tol: float) -> None:
		"""SCPI: [SENSe]:CREFerence:HARMonics:TOLerance \n
		Snippet: driver.applications.k50Spurious.sense.creference.harmonics.tolerance.set(tol = 1.0) \n
		Sets the frequency tolerance to match harmonics to measured spurs. \n
			:param tol: numeric value Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(tol)
		self._core.io.write(f'SENSe:CREFerence:HARMonics:TOLerance {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CREFerence:HARMonics:TOLerance \n
		Snippet: value: float = driver.applications.k50Spurious.sense.creference.harmonics.tolerance.get() \n
		Sets the frequency tolerance to match harmonics to measured spurs. \n
			:return: tol: No help available"""
		response = self._core.io.query_str(f'SENSe:CREFerence:HARMonics:TOLerance?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPyCls:
	"""FilterPy commands group definition. 13 total commands, 6 Subgroups, 0 group commands
	Repeated Capability: FilterPy, default value after init: FilterPy.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_filterPy_get', 'repcap_filterPy_set', repcap.FilterPy.Nr1)

	def repcap_filterPy_set(self, filterPy: repcap.FilterPy) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FilterPy.Default
		Default value after init: FilterPy.Nr1"""
		self._cmd_group.set_repcap_enum_value(filterPy)

	def repcap_filterPy_get(self) -> repcap.FilterPy:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def hpass(self):
		"""hpass commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_hpass'):
			from .Hpass import HpassCls
			self._hpass = HpassCls(self._core, self._cmd_group)
		return self._hpass

	@property
	def lpass(self):
		"""lpass commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_lpass'):
			from .Lpass import LpassCls
			self._lpass = LpassCls(self._core, self._cmd_group)
		return self._lpass

	@property
	def demphasis(self):
		"""demphasis commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_demphasis'):
			from .Demphasis import DemphasisCls
			self._demphasis = DemphasisCls(self._core, self._cmd_group)
		return self._demphasis

	@property
	def ccir(self):
		"""ccir commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccir'):
			from .Ccir import CcirCls
			self._ccir = CcirCls(self._core, self._cmd_group)
		return self._ccir

	@property
	def aweighted(self):
		"""aweighted commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_aweighted'):
			from .Aweighted import AweightedCls
			self._aweighted = AweightedCls(self._core, self._cmd_group)
		return self._aweighted

	@property
	def aoff(self):
		"""aoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aoff'):
			from .Aoff import AoffCls
			self._aoff = AoffCls(self._core, self._cmd_group)
		return self._aoff

	def clone(self) -> 'FilterPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def get(self, trace_type: enums.TraceTypeDdem, window=repcap.Window.Default) -> List[float]:
		"""SCPI: TRACe<n>[:DATA] \n
		Snippet: value: List[float] = driver.applications.k70Vsa.trace.data.get(trace_type = enums.TraceTypeDdem.MSTRace, window = repcap.Window.Default) \n
		This command queries the trace data. Which data is returned depends on the result display in the window specified by the
		suffix <n>. For details see 'Measurement results for TRACe<n>[:DATA]? TRACE<n>'. \n
			:param trace_type: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: trace_ydata: No help available"""
		param = Conversions.enum_scalar_to_str(trace_type, enums.TraceTypeDdem)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe{window_cmd_val}:DATA? {param}')
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HighCls:
	"""High commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("high", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: [SENSe]:MIXer:LOSS:TABLe:HIGH \n
		Snippet: driver.sense.mixer.loss.table.high.set(filename = '1') \n
		This command defines the conversion loss table to be used for the high (second) range. \n
			:param filename: String containing the path and name of the file, or the serial number of the external mixer whose file is required. The R&S FSWP automatically selects the correct cvl file for the current IF. As an alternative, you can also select a user-defined conversion loss table (.acl file) .
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SENSe:MIXer:LOSS:TABLe:HIGH {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:MIXer:LOSS:TABLe:HIGH \n
		Snippet: value: str = driver.sense.mixer.loss.table.high.get() \n
		This command defines the conversion loss table to be used for the high (second) range. \n
			:return: filename: String containing the path and name of the file, or the serial number of the external mixer whose file is required. The R&S FSWP automatically selects the correct cvl file for the current IF. As an alternative, you can also select a user-defined conversion loss table (.acl file) ."""
		response = self._core.io.query_str(f'SENSe:MIXer:LOSS:TABLe:HIGH?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ControlCls:
	"""Control commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("control", core, parent)

	def set(self, step: enums.MeasurementStep) -> None:
		"""SCPI: [SENSe]:SSEarch:CONTrol \n
		Snippet: driver.applications.k50Spurious.sense.ssearch.control.set(step = enums.MeasurementStep.NESTimate) \n
		Defines which steps of the measurement process are performed. All steps up to the selected step are performed. By default,
		all measurement steps are performed. For details on the measurement process steps see 'Measurement process'. \n
			:param step: SOVerview | NESTimate | SDETection | SPOTstep SOVerview Spectral overview only NESTimate Spectral overview and Noise Floor Estimation SDETection Spectral overview, Noise Floor Estimation, and Spurious Detection measurement SPOT Spot Search - all measurement steps are performed
		"""
		param = Conversions.enum_scalar_to_str(step, enums.MeasurementStep)
		self._core.io.write(f'SENSe:SSEarch:CONTrol {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MeasurementStep:
		"""SCPI: [SENSe]:SSEarch:CONTrol \n
		Snippet: value: enums.MeasurementStep = driver.applications.k50Spurious.sense.ssearch.control.get() \n
		Defines which steps of the measurement process are performed. All steps up to the selected step are performed. By default,
		all measurement steps are performed. For details on the measurement process steps see 'Measurement process'. \n
			:return: step: SOVerview | NESTimate | SDETection | SPOTstep SOVerview Spectral overview only NESTimate Spectral overview and Noise Floor Estimation SDETection Spectral overview, Noise Floor Estimation, and Spurious Detection measurement SPOT Spot Search - all measurement steps are performed"""
		response = self._core.io.query_str(f'SENSe:SSEarch:CONTrol?')
		return Conversions.str_to_scalar_enum(response, enums.MeasurementStep)
